# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.tenant.v1 import tenant_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2


class TenantServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTenants = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/ListTenants',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.FromString,
                )
        self.CreateTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/CreateTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.FromString,
                )
        self.GetTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/GetTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.FromString,
                )
        self.UpdateTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/UpdateTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.FromString,
                )
        self.DeleteTenant = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/DeleteTenant',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.FromString,
                )


class TenantServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListTenants(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTenant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TenantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTenants': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTenants,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.SerializeToString,
            ),
            'CreateTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.SerializeToString,
            ),
            'GetTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.SerializeToString,
            ),
            'UpdateTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.SerializeToString,
            ),
            'DeleteTenant': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTenant,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.tenant.v1.TenantService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TenantService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListTenants(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/ListTenants',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.ListTenantsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/CreateTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.CreateTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/GetTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.GetTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/UpdateTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.UpdateTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTenant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.tenant.v1.TenantService/DeleteTenant',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_tenant_dot_v1_dot_tenant__pb2.DeleteTenantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/modelautobuilder/v1/modelautobuilder.proto\x12:github.com.metaprov.modelaapi.services.modelautobuilder.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x8f\x02\n\x1cListModelAutobuildersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1dListModelAutobuildersResponse\x12i\n\x11modelautobuilders\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilderList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x01\n\x1d\x43reateModelAutobuilderRequest\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\" \n\x1e\x43reateModelAutobuilderResponse\"\xb5\x01\n\x1dUpdateModelAutobuilderRequest\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateModelAutobuilderResponse\"=\n\x1aGetModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x01\n\x1bGetModelAutobuilderResponse\x12\x64\n\x10modelautobuilder\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelAutobuilderResponse2\xc1\n\n\x17ModelAutobuilderService\x12\xf7\x01\n\x15ListModelAutobuilders\x12X.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest\x1aY.github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/modelautobuilders/{namespace}\x12\xf1\x01\n\x16\x43reateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelautobuilders:\x01*\x12\xf8\x01\n\x13GetModelAutobuilder\x12V.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest\x1aW.github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/modelautobuilders/{namespace}/{name}\x12\xb8\x02\n\x16UpdateModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse\"g\x82\xd3\xe4\x93\x02\x61\x1a\\/v1/modelautobuilders/{modelautobuilder.metadata.namespace}/{modelautobuilder.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteModelAutobuilder\x12Y.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest\x1aZ.github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse\"0\x82\xd3\xe4\x93\x02**(/v1/modelautobuilders/{namespace}/{name}B<Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1b\x06proto3')



_LISTMODELAUTOBUILDERSREQUEST = DESCRIPTOR.message_types_by_name['ListModelAutobuildersRequest']
_LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY = _LISTMODELAUTOBUILDERSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELAUTOBUILDERSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelAutobuildersResponse']
_CREATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['CreateModelAutobuilderRequest']
_CREATEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelAutobuilderResponse']
_UPDATEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderRequest']
_UPDATEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderResponse']
_GETMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['GetModelAutobuilderRequest']
_GETMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['GetModelAutobuilderResponse']
_DELETEMODELAUTOBUILDERREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderRequest']
_DELETEMODELAUTOBUILDERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderResponse']
ListModelAutobuildersRequest = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersRequest)
  })
_sym_db.RegisterMessage(ListModelAutobuildersRequest)
_sym_db.RegisterMessage(ListModelAutobuildersRequest.LabelsEntry)

ListModelAutobuildersResponse = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.ListModelAutobuildersResponse)
  })
_sym_db.RegisterMessage(ListModelAutobuildersResponse)

CreateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderRequest)

CreateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.CreateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderResponse)

UpdateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderRequest)

UpdateModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.UpdateModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderResponse)

GetModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(GetModelAutobuilderRequest)

GetModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.GetModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(GetModelAutobuilderResponse)

DeleteModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderRequest)

DeleteModelAutobuilderResponse = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelautobuilder.v1.modelautobuilder_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelautobuilder.v1.DeleteModelAutobuilderResponse)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderResponse)

_MODELAUTOBUILDERSERVICE = DESCRIPTOR.services_by_name['ModelAutobuilderService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/modelautobuilder/v1'
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._options = None
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELAUTOBUILDERSERVICE.methods_by_name['ListModelAutobuilders']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['ListModelAutobuilders']._serialized_options = b'\202\323\344\223\002#\022!/v1/modelautobuilders/{namespace}'
  _MODELAUTOBUILDERSERVICE.methods_by_name['CreateModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['CreateModelAutobuilder']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/modelautobuilders:\001*'
  _MODELAUTOBUILDERSERVICE.methods_by_name['GetModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['GetModelAutobuilder']._serialized_options = b'\202\323\344\223\002*\022(/v1/modelautobuilders/{namespace}/{name}'
  _MODELAUTOBUILDERSERVICE.methods_by_name['UpdateModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['UpdateModelAutobuilder']._serialized_options = b'\202\323\344\223\002a\032\\/v1/modelautobuilders/{modelautobuilder.metadata.namespace}/{modelautobuilder.metadata.name}:\001*'
  _MODELAUTOBUILDERSERVICE.methods_by_name['DeleteModelAutobuilder']._options = None
  _MODELAUTOBUILDERSERVICE.methods_by_name['DeleteModelAutobuilder']._serialized_options = b'\202\323\344\223\002**(/v1/modelautobuilders/{namespace}/{name}'
  _LISTMODELAUTOBUILDERSREQUEST._serialized_start=284
  _LISTMODELAUTOBUILDERSREQUEST._serialized_end=555
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_start=510
  _LISTMODELAUTOBUILDERSREQUEST_LABELSENTRY._serialized_end=555
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_start=558
  _LISTMODELAUTOBUILDERSRESPONSE._serialized_end=721
  _CREATEMODELAUTOBUILDERREQUEST._serialized_start=724
  _CREATEMODELAUTOBUILDERREQUEST._serialized_end=857
  _CREATEMODELAUTOBUILDERRESPONSE._serialized_start=859
  _CREATEMODELAUTOBUILDERRESPONSE._serialized_end=891
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_start=894
  _UPDATEMODELAUTOBUILDERREQUEST._serialized_end=1075
  _UPDATEMODELAUTOBUILDERRESPONSE._serialized_start=1077
  _UPDATEMODELAUTOBUILDERRESPONSE._serialized_end=1109
  _GETMODELAUTOBUILDERREQUEST._serialized_start=1111
  _GETMODELAUTOBUILDERREQUEST._serialized_end=1172
  _GETMODELAUTOBUILDERRESPONSE._serialized_start=1175
  _GETMODELAUTOBUILDERRESPONSE._serialized_end=1320
  _DELETEMODELAUTOBUILDERREQUEST._serialized_start=1322
  _DELETEMODELAUTOBUILDERREQUEST._serialized_end=1386
  _DELETEMODELAUTOBUILDERRESPONSE._serialized_start=1388
  _DELETEMODELAUTOBUILDERRESPONSE._serialized_end=1420
  _MODELAUTOBUILDERSERVICE._serialized_start=1423
  _MODELAUTOBUILDERSERVICE._serialized_end=2768
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featurepipeline.v1 import featurepipeline_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2


class FeaturePipelineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeaturePipelines = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/ListFeaturePipelines',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineResponse.FromString,
                )
        self.CreateFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/CreateFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineResponse.FromString,
                )
        self.GetFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/GetFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineResponse.FromString,
                )
        self.UpdateFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/UpdateFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineResponse.FromString,
                )
        self.DeleteFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/DeleteFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineResponse.FromString,
                )
        self.PauseFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/PauseFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineResponse.FromString,
                )
        self.ResumeFeaturePipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/ResumeFeaturePipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineResponse.FromString,
                )


class FeaturePipelineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeaturePipelines(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeFeaturePipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturePipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeaturePipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturePipelines,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineResponse.SerializeToString,
            ),
            'CreateFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineResponse.SerializeToString,
            ),
            'GetFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineResponse.SerializeToString,
            ),
            'UpdateFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineResponse.SerializeToString,
            ),
            'DeleteFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineResponse.SerializeToString,
            ),
            'PauseFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineResponse.SerializeToString,
            ),
            'ResumeFeaturePipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeFeaturePipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturePipelineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeaturePipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/ListFeaturePipelines',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ListFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/CreateFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.CreateFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/GetFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.GetFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/UpdateFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.UpdateFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/DeleteFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.DeleteFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/PauseFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.PauseFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeFeaturePipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipeline.v1.FeaturePipelineService/ResumeFeaturePipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipeline_dot_v1_dot_featurepipeline__pb2.ResumeFeaturePipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelpipeline.v1 import modelpipeline_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2


class ModelPipelineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelPipelines = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/ListModelPipelines',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesResponse.FromString,
                )
        self.CreateModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/CreateModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineResponse.FromString,
                )
        self.GetModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/GetModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineResponse.FromString,
                )
        self.UpdateModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/UpdateModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineResponse.FromString,
                )
        self.DeleteModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/DeleteModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineResponse.FromString,
                )
        self.RunModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/RunModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineResponse.FromString,
                )
        self.PauseModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/PauseModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineResponse.FromString,
                )
        self.ResumeModelPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/ResumeModelPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineResponse.FromString,
                )


class ModelPipelineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelPipelines(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeModelPipeline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelPipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelPipelines,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesResponse.SerializeToString,
            ),
            'CreateModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineResponse.SerializeToString,
            ),
            'GetModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineResponse.SerializeToString,
            ),
            'UpdateModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineResponse.SerializeToString,
            ),
            'DeleteModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineResponse.SerializeToString,
            ),
            'RunModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.RunModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineResponse.SerializeToString,
            ),
            'PauseModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineResponse.SerializeToString,
            ),
            'ResumeModelPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeModelPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPipelineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelPipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/ListModelPipelines',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ListModelPipelinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/CreateModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.CreateModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/GetModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.GetModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/UpdateModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.UpdateModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/DeleteModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.DeleteModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/RunModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.RunModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/PauseModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.PauseModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeModelPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService/ResumeModelPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipeline_dot_v1_dot_modelpipeline__pb2.ResumeModelPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featurepipelinerun.v1 import featurepipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2


class FeaturePipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeaturePipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/ListFeaturePipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.FromString,
                )
        self.CreateFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/CreateFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.FromString,
                )
        self.GetFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/GetFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.FromString,
                )
        self.UpdateFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/UpdateFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.FromString,
                )
        self.DeleteFeaturePipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/DeleteFeaturePipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.FromString,
                )


class FeaturePipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeaturePipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeaturePipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeaturePipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeaturePipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeaturePipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.SerializeToString,
            ),
            'CreateFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.SerializeToString,
            ),
            'GetFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.SerializeToString,
            ),
            'UpdateFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.SerializeToString,
            ),
            'DeleteFeaturePipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeaturePipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeaturePipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeaturePipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/ListFeaturePipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.ListFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/CreateFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.CreateFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/GetFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.GetFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/UpdateFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.UpdateFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeaturePipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurepipelinerun.v1.FeaturePipelineRunService/DeleteFeaturePipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurepipelinerun_dot_v1_dot_featurepipelinerun__pb2.DeleteFeaturePipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/featurepipeline/v1/featurepipeline.proto\x12\x39github.com.metaprov.modelaapi.services.featurepipeline.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x8a\x02\n\x1aListFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1bListFeaturePipelineResponse\x12\x63\n\x10\x66\x65\x61turepipelines\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x1c\x43reateFeaturePipelineRequest\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x1f\n\x1d\x43reateFeaturePipelineResponse\"\xae\x01\n\x1cUpdateFeaturePipelineRequest\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1f\n\x1dUpdateFeaturePipelineResponse\"<\n\x19GetFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8a\x01\n\x1aGetFeaturePipelineResponse\x12^\n\x0f\x66\x65\x61turepipeline\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteFeaturePipelineResponse\"\x1e\n\x1cPauseFeaturePipelineResponse\">\n\x1bPauseFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1dResumeFeaturePipelineResponse\"?\n\x1cResumeFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa3\x0e\n\x16\x46\x65\x61turePipelineService\x12\xef\x01\n\x14ListFeaturePipelines\x12U.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest\x1aV.github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/featurepipelines/{namespace}\x12\xeb\x01\n\x15\x43reateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/featurepipelines:\x01*\x12\xf2\x01\n\x12GetFeaturePipeline\x12T.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest\x1aU.github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/featurepipelines/{namespace}/{name}\x12\xb0\x02\n\x15UpdateFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse\"d\x82\xd3\xe4\x93\x02^\x1aY/v1/featurepipelines/{featurepipeline.metadata.namespace}/{featurepipeline.metadata.name}:\x01*\x12\xfb\x01\n\x15\x44\x65leteFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse\"/\x82\xd3\xe4\x93\x02)*\'/v1/featurepipelines/{namespace}/{name}\x12\xfe\x01\n\x14PauseFeaturePipeline\x12V.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest\x1aW.github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/featurepipelines/{namespace}/{name}:pause\x12\x81\x02\n\x15ResumeFeaturePipeline\x12W.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest\x1aX.github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse\"5\x82\xd3\xe4\x93\x02/\"-/v1/featurepipelines/{namespace}/{name}:pauseB;Z9github.com/metaprov/modelaapi/services/featurepipeline/v1b\x06proto3')



_LISTFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRequest']
_LISTFEATUREPIPELINEREQUEST_LABELSENTRY = _LISTFEATUREPIPELINEREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelineResponse']
_CREATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRequest']
_CREATEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineResponse']
_UPDATEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRequest']
_UPDATEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineResponse']
_GETFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRequest']
_GETFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturePipelineResponse']
_DELETEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRequest']
_DELETEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineResponse']
_PAUSEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['PauseFeaturePipelineResponse']
_PAUSEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['PauseFeaturePipelineRequest']
_RESUMEFEATUREPIPELINERESPONSE = DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineResponse']
_RESUMEFEATUREPIPELINEREQUEST = DESCRIPTOR.message_types_by_name['ResumeFeaturePipelineRequest']
ListFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRequest.LabelsEntry)

ListFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ListFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineResponse)

CreateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRequest)

CreateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.CreateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineResponse)

UpdateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRequest)

UpdateFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.UpdateFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineResponse)

GetFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRequest)

GetFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.GetFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineResponse)

DeleteFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRequest)

DeleteFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.DeleteFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineResponse)

PauseFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineResponse)

PauseFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('PauseFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.PauseFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(PauseFeaturePipelineRequest)

ResumeFeaturePipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineResponse)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineResponse)

ResumeFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipeline.v1.featurepipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipeline.v1.ResumeFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(ResumeFeaturePipelineRequest)

_FEATUREPIPELINESERVICE = DESCRIPTOR.services_by_name['FeaturePipelineService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/featurepipeline/v1'
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._options = None
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREPIPELINESERVICE.methods_by_name['ListFeaturePipelines']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['ListFeaturePipelines']._serialized_options = b'\202\323\344\223\002\"\022 /v1/featurepipelines/{namespace}'
  _FEATUREPIPELINESERVICE.methods_by_name['CreateFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['CreateFeaturePipeline']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/featurepipelines:\001*'
  _FEATUREPIPELINESERVICE.methods_by_name['GetFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['GetFeaturePipeline']._serialized_options = b'\202\323\344\223\002)\022\'/v1/featurepipelines/{namespace}/{name}'
  _FEATUREPIPELINESERVICE.methods_by_name['UpdateFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['UpdateFeaturePipeline']._serialized_options = b'\202\323\344\223\002^\032Y/v1/featurepipelines/{featurepipeline.metadata.namespace}/{featurepipeline.metadata.name}:\001*'
  _FEATUREPIPELINESERVICE.methods_by_name['DeleteFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['DeleteFeaturePipeline']._serialized_options = b'\202\323\344\223\002)*\'/v1/featurepipelines/{namespace}/{name}'
  _FEATUREPIPELINESERVICE.methods_by_name['PauseFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['PauseFeaturePipeline']._serialized_options = b'\202\323\344\223\002/\"-/v1/featurepipelines/{namespace}/{name}:pause'
  _FEATUREPIPELINESERVICE.methods_by_name['ResumeFeaturePipeline']._options = None
  _FEATUREPIPELINESERVICE.methods_by_name['ResumeFeaturePipeline']._serialized_options = b'\202\323\344\223\002/\"-/v1/featurepipelines/{namespace}/{name}:pause'
  _LISTFEATUREPIPELINEREQUEST._serialized_start=277
  _LISTFEATUREPIPELINEREQUEST._serialized_end=543
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_start=498
  _LISTFEATUREPIPELINEREQUEST_LABELSENTRY._serialized_end=543
  _LISTFEATUREPIPELINERESPONSE._serialized_start=546
  _LISTFEATUREPIPELINERESPONSE._serialized_end=701
  _CREATEFEATUREPIPELINEREQUEST._serialized_start=703
  _CREATEFEATUREPIPELINEREQUEST._serialized_end=829
  _CREATEFEATUREPIPELINERESPONSE._serialized_start=831
  _CREATEFEATUREPIPELINERESPONSE._serialized_end=862
  _UPDATEFEATUREPIPELINEREQUEST._serialized_start=865
  _UPDATEFEATUREPIPELINEREQUEST._serialized_end=1039
  _UPDATEFEATUREPIPELINERESPONSE._serialized_start=1041
  _UPDATEFEATUREPIPELINERESPONSE._serialized_end=1072
  _GETFEATUREPIPELINEREQUEST._serialized_start=1074
  _GETFEATUREPIPELINEREQUEST._serialized_end=1134
  _GETFEATUREPIPELINERESPONSE._serialized_start=1137
  _GETFEATUREPIPELINERESPONSE._serialized_end=1275
  _DELETEFEATUREPIPELINEREQUEST._serialized_start=1277
  _DELETEFEATUREPIPELINEREQUEST._serialized_end=1340
  _DELETEFEATUREPIPELINERESPONSE._serialized_start=1342
  _DELETEFEATUREPIPELINERESPONSE._serialized_end=1373
  _PAUSEFEATUREPIPELINERESPONSE._serialized_start=1375
  _PAUSEFEATUREPIPELINERESPONSE._serialized_end=1405
  _PAUSEFEATUREPIPELINEREQUEST._serialized_start=1407
  _PAUSEFEATUREPIPELINEREQUEST._serialized_end=1469
  _RESUMEFEATUREPIPELINERESPONSE._serialized_start=1471
  _RESUMEFEATUREPIPELINERESPONSE._serialized_end=1502
  _RESUMEFEATUREPIPELINEREQUEST._serialized_start=1504
  _RESUMEFEATUREPIPELINEREQUEST._serialized_end=1567
  _FEATUREPIPELINESERVICE._serialized_start=1570
  _FEATUREPIPELINESERVICE._serialized_end=3397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQgithub.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto\x12:github.com.metaprov.modelaapi.services.modelcompilerrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\x8f\x02\n\x1cListModelCompilerRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x01\n\x1dListModelCompilerRunsResponse\x12i\n\x11modelcompilerruns\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18ModelCompilerRunResponse\"\x85\x01\n\x1d\x43reateModelCompilerRunRequest\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1e\x43reateModelCompilerRunResponse\"\xb5\x01\n\x1dUpdateModelCompilerRunRequest\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\" \n\x1eUpdateModelCompilerRunResponse\"=\n\x1aGetModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x91\x01\n\x1bGetModelCompilerRunResponse\x12\x64\n\x10modelcompilerrun\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelCompilerRunResponse2\xc1\n\n\x17ModelCompilerRunService\x12\xf7\x01\n\x15ListModelCompilerRuns\x12X.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/modelcompilerruns/{namespace}\x12\xf1\x01\n\x16\x43reateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/modelcompilerruns:\x01*\x12\xf8\x01\n\x13GetModelCompilerRun\x12V.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse\"0\x82\xd3\xe4\x93\x02*\x12(/v1/modelcompilerruns/{namespace}/{name}\x12\xb8\x02\n\x16UpdateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse\"g\x82\xd3\xe4\x93\x02\x61\x1a\\/v1/modelcompilerruns/{modelcompilerrun.metadata.namespace}/{modelcompilerrun.metadata.name}:\x01*\x12\x81\x02\n\x16\x44\x65leteModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse\"0\x82\xd3\xe4\x93\x02**(/v1/modelcompilerruns/{namespace}/{name}B<Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1b\x06proto3')



_LISTMODELCOMPILERRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListModelCompilerRunsRequest']
_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY = _LISTMODELCOMPILERRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMODELCOMPILERRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListModelCompilerRunsResponse']
_MODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['ModelCompilerRunResponse']
_CREATEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateModelCompilerRunRequest']
_CREATEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelCompilerRunResponse']
_UPDATEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunRequest']
_UPDATEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunResponse']
_GETMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['GetModelCompilerRunRequest']
_GETMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetModelCompilerRunResponse']
_DELETEMODELCOMPILERRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunRequest']
_DELETEMODELCOMPILERRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunResponse']
ListModelCompilerRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsRequest)
_sym_db.RegisterMessage(ListModelCompilerRunsRequest.LabelsEntry)

ListModelCompilerRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsResponse)

ModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('ModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(ModelCompilerRunResponse)

CreateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunRequest)

CreateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunResponse)

UpdateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunRequest)

UpdateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunResponse)

GetModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(GetModelCompilerRunRequest)

GetModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(GetModelCompilerRunResponse)

DeleteModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunRequest)

DeleteModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunResponse)

_MODELCOMPILERRUNSERVICE = DESCRIPTOR.services_by_name['ModelCompilerRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1'
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._options = None
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MODELCOMPILERRUNSERVICE.methods_by_name['ListModelCompilerRuns']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['ListModelCompilerRuns']._serialized_options = b'\202\323\344\223\002#\022!/v1/modelcompilerruns/{namespace}'
  _MODELCOMPILERRUNSERVICE.methods_by_name['CreateModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['CreateModelCompilerRun']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/modelcompilerruns:\001*'
  _MODELCOMPILERRUNSERVICE.methods_by_name['GetModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['GetModelCompilerRun']._serialized_options = b'\202\323\344\223\002*\022(/v1/modelcompilerruns/{namespace}/{name}'
  _MODELCOMPILERRUNSERVICE.methods_by_name['UpdateModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['UpdateModelCompilerRun']._serialized_options = b'\202\323\344\223\002a\032\\/v1/modelcompilerruns/{modelcompilerrun.metadata.namespace}/{modelcompilerrun.metadata.name}:\001*'
  _MODELCOMPILERRUNSERVICE.methods_by_name['DeleteModelCompilerRun']._options = None
  _MODELCOMPILERRUNSERVICE.methods_by_name['DeleteModelCompilerRun']._serialized_options = b'\202\323\344\223\002**(/v1/modelcompilerruns/{namespace}/{name}'
  _LISTMODELCOMPILERRUNSREQUEST._serialized_start=284
  _LISTMODELCOMPILERRUNSREQUEST._serialized_end=555
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_start=510
  _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._serialized_end=555
  _LISTMODELCOMPILERRUNSRESPONSE._serialized_start=558
  _LISTMODELCOMPILERRUNSRESPONSE._serialized_end=721
  _MODELCOMPILERRUNRESPONSE._serialized_start=723
  _MODELCOMPILERRUNRESPONSE._serialized_end=749
  _CREATEMODELCOMPILERRUNREQUEST._serialized_start=752
  _CREATEMODELCOMPILERRUNREQUEST._serialized_end=885
  _CREATEMODELCOMPILERRUNRESPONSE._serialized_start=887
  _CREATEMODELCOMPILERRUNRESPONSE._serialized_end=919
  _UPDATEMODELCOMPILERRUNREQUEST._serialized_start=922
  _UPDATEMODELCOMPILERRUNREQUEST._serialized_end=1103
  _UPDATEMODELCOMPILERRUNRESPONSE._serialized_start=1105
  _UPDATEMODELCOMPILERRUNRESPONSE._serialized_end=1137
  _GETMODELCOMPILERRUNREQUEST._serialized_start=1139
  _GETMODELCOMPILERRUNREQUEST._serialized_end=1200
  _GETMODELCOMPILERRUNRESPONSE._serialized_start=1203
  _GETMODELCOMPILERRUNRESPONSE._serialized_end=1348
  _DELETEMODELCOMPILERRUNREQUEST._serialized_start=1350
  _DELETEMODELCOMPILERRUNREQUEST._serialized_end=1414
  _DELETEMODELCOMPILERRUNRESPONSE._serialized_start=1416
  _DELETEMODELCOMPILERRUNRESPONSE._serialized_end=1448
  _MODELCOMPILERRUNSERVICE._serialized_start=1451
  _MODELCOMPILERRUNSERVICE._serialized_end=2796
# @@protoc_insertion_point(module_scope)
